@@ -1,4 +1,4 @@
-package Concierge::Users::Meta v0.7.0;
+package Concierge::Users::Meta v0.7.1;
 use v5.36;
 use Carp qw/ croak carp /;
 use YAML::Tiny;
@@ -1102,7 +1102,7 @@ utilities for Concierge::Users
 
 =head1 VERSION
 
-v0.7.0
+v0.7.1
 
 =head1 SYNOPSIS
 
@@ -1182,6 +1182,10 @@ Account status for access control.
     null_value:    ""
     must_validate: 1
 
+This is a core field (always present), but its C<options> can be
+replaced via C<field_overrides> to match your application's workflow.
+See L</Field Overrides> for an example.
+
 =item B<access_level>
 
 Permission level for feature access.
@@ -1195,6 +1199,9 @@ Permission level for feature access.
     null_value:    ""
     must_validate: 1
 
+Core field (always present); C<options> can be replaced via
+C<field_overrides>.  See L</Field Overrides>.
+
 =back
 
 =head2 Standard Fields (12)
@@ -1471,6 +1478,24 @@ warning.
 
 =back
 
+B<Overriding enum options:>  Core fields like C<user_status> and
+C<access_level> are always present, but their C<options> are not
+fixed.  Replace them with values that fit your domain:
+
+    # Makerspace member status instead of the default
+    # Eligible / OK / Inactive
+    field_overrides => [
+        {
+            field_name => 'user_status',
+            options    => [qw( *Applicant Novice Skilled
+                               Expert Mentor Steward )],
+        },
+    ],
+
+The C<*>-prefixed option becomes the default (see L</Enum Default
+Convention>).  Validation, filtering, and all other enum behaviors
+apply to the new option set automatically.
+
 =head2 Enum Default Convention
 
 In an C<options> arrayref, prefix exactly one value with C<*> to mark it
@@ -1652,7 +1677,7 @@ __DATA__
 ################################################################################
 
 Configuration:
-  Version: v0.7.0
+  Version: v0.7.1
   Backend: Concierge::Users::Database  # Default; can be 'database', 'file', or 'yaml'
   Storage Directory: /path/to/storage  # Set during setup
   Generated: 2026-01-06 19:10:18
